Index: base/process/kill.h |
diff --git a/base/process/kill.h b/base/process/kill.h |
index f697701689aff934a167323de011270759296c1f..e8ce3340b04c6dee73b28e37f0a31f949a7ff969 100644 |
--- a/base/process/kill.h |
+++ b/base/process/kill.h |
@@ -154,8 +154,8 @@ BASE_EXPORT void EnsureProcessTerminated(Process process); |
#if defined(OS_POSIX) && !defined(OS_MACOSX) |
// The nicer version of EnsureProcessTerminated() that is patient and will |
-// wait for |process_handle| to finish and then reap it. |
-BASE_EXPORT void EnsureProcessGetsReaped(ProcessHandle process_handle); |
+// wait for |pid| to finish and then reap it. |
+BASE_EXPORT void EnsureProcessGetsReaped(ProcessId pid); |
#endif |
} // namespace base |